"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7948899b3068

from __future__ import annotations
from .connectorcalltoolrequest import (
    ConnectorCallToolRequest,
    ConnectorCallToolRequestTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectorCallToolV1RequestTypedDict(TypedDict):
    tool_name: str
    connector_id_or_name: str
    connector_call_tool_request: ConnectorCallToolRequestTypedDict
    credentials_name: NotRequired[Nullable[str]]


class ConnectorCallToolV1Request(BaseModel):
    tool_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    connector_id_or_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    connector_call_tool_request: Annotated[
        ConnectorCallToolRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    credentials_name: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["credentials_name"])
        nullable_fields = set(["credentials_name"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
