"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7033fdb33ad4

from __future__ import annotations
from .audioformat import AudioFormat, AudioFormatTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class RealtimeTranscriptionSessionUpdatePayloadTypedDict(TypedDict):
    audio_format: NotRequired[Nullable[AudioFormatTypedDict]]
    r"""Set before sending audio. Audio format updates are rejected after audio starts."""
    target_streaming_delay_ms: NotRequired[Nullable[int]]
    r"""Set before sending audio. Streaming delay updates are rejected after audio starts."""


class RealtimeTranscriptionSessionUpdatePayload(BaseModel):
    audio_format: OptionalNullable[AudioFormat] = UNSET
    r"""Set before sending audio. Audio format updates are rejected after audio starts."""

    target_streaming_delay_ms: OptionalNullable[int] = UNSET
    r"""Set before sending audio. Streaming delay updates are rejected after audio starts."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["audio_format", "target_streaming_delay_ms"])
        nullable_fields = set(["audio_format", "target_streaming_delay_ms"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
