"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5ec0889995f5

from __future__ import annotations
from .connectorsqueryfilters import (
    ConnectorsQueryFilters,
    ConnectorsQueryFiltersTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectorListV1RequestTypedDict(TypedDict):
    query_filters: NotRequired[ConnectorsQueryFiltersTypedDict]
    cursor: NotRequired[Nullable[str]]
    page_size: NotRequired[int]


class ConnectorListV1Request(BaseModel):
    query_filters: Annotated[
        Optional[ConnectorsQueryFilters],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    cursor: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["query_filters", "cursor", "page_size"])
        nullable_fields = set(["cursor"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
