"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 0ae165cc7a82

from __future__ import annotations
from .workflow import Workflow, WorkflowTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class WorkflowUpdateResponseTypedDict(TypedDict):
    workflow: WorkflowTypedDict


class WorkflowUpdateResponse(BaseModel):
    workflow: Workflow
